@@ -13,7 +13,7 @@ from django.contrib.auth.admin import UserAdmin as UserAdminBase, GroupAdmin as
 from django.contrib import admin, auth
 from django.contrib.admin.util import flatten_fieldsets
 from django.core.exceptions import PermissionDenied
-from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse, reverse_lazy
 from django.core.mail import send_mail
 from django.db import transaction
 from django.db.models import Count
@@ -245,8 +245,10 @@ class UserAdmin(UserAdminBase, AdminBase):
     def get_urls(self):
         """Returns the URLs used by this admin class."""
         urlpatterns = super(UserAdmin, self).get_urls()
-        admin_view = self.admin_site.admin_view
+        admin_site = self.admin_site
+        admin_view = admin_site.admin_view
         urlpatterns = patterns("",
+            # User invite.
             url("^invite/$", admin_view(self.invite_user), name="auth_user_invite"),
             url("^invite/(?P<uidb36>[^-]+)-(?P<token>[^/]+)/$", self.invite_user_confirm, name="auth_user_invite_confirm"),
         ) + urlpatterns
