@@ -3,6 +3,7 @@
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.validators import MaxLengthValidator
+from django.utils.encoding import force_text
 
 
 ORIGINAL_USERNAME_MAX_LENGTH = USERNAME_MAX_LENGTH = User._meta.get_field("username").max_length
@@ -22,7 +23,7 @@ if "south" in settings.INSTALLED_APPS and getattr(settings, "SOUTH_MIGRATION_MOD
             if isinstance(validator, MaxLengthValidator):
                 validator.limit_value = USERNAME_MAX_LENGTH
         field.max_length = USERNAME_MAX_LENGTH
-        field.help_text = field.help_text.replace(unicode(ORIGINAL_USERNAME_MAX_LENGTH), unicode(USERNAME_MAX_LENGTH))
+        field.help_text = field.help_text.replace(force_text(ORIGINAL_USERNAME_MAX_LENGTH), force_text(USERNAME_MAX_LENGTH))
         if hasattr(field, "widget"):
             field.widget.attrs["maxlength"] = USERNAME_MAX_LENGTH
     patch_username_field(User._meta.get_field("username"))
\ No newline at end of file
